# pyAdalight

### Installation
```shell
$ pip install pyadalight
```

### Usage
```shell
$ pyadalight --help
Usage: pyadalight [OPTIONS]

Options:
  -hl, --h-led-count INTEGER  Horizontal LED count.
  -vl, --v-led-count INTEGER  Vertical LED count.
  -p, --port TEXT             Serial port.
  -m, --monitor INTEGER       Monitor index.
  --list-monitors             Shows monitors list and exits.
  --list-ports                Shows ports list and exits.
  --help                      Show this message and exit.

```

### License
The source is released under MIT-License (see https://opensource.org/licenses/MIT).
